@@ -28,8 +28,16 @@
 
 #include <glib.h>
 
+#include "parole-gst.h"
+
+#if GST_CHECK_VERSION(1, 0, 0)
+#include <gst/video/videooverlay.h>
+#include <gst/video/navigation.h>
+#else
 #include <gst/interfaces/xoverlay.h>
 #include <gst/interfaces/navigation.h>
+#endif
+
 #include <gst/pbutils/missing-plugins.h>
 #include <gst/pbutils/install-plugins.h>
 
@@ -41,8 +49,6 @@
 
 #include <gdk/gdkx.h>
 
-#include "parole-gst.h"
-
 #include "common/parole-common.h"
 
 #include "parole-utils.h"
@@ -63,7 +69,9 @@ static void     parole_gst_change_state 	(ParoleGst *gst,
 static void	parole_gst_terminate_internal   (ParoleGst *gst, 
 						 gboolean fade_sound);
 						 
-static gchar * parole_gst_tag_list_get_cover_external (ParoleGst *gst);
+static GdkPixbuf * parole_gst_tag_list_get_cover_external (ParoleGst *gst);
+
+static GdkPixbuf * parole_gst_tag_list_get_cover_embedded (ParoleGst *gst, GstTagList *tag_list);
 						 
 static GdkPixbuf * parole_gst_tag_list_get_cover (ParoleGst *gst, GstTagList *tag_list);
 
@@ -351,7 +359,7 @@ parole_gst_get_video_output_size (ParoleGst *gst, gint *ret_w, gint *ret_h)
 		    else 
 		    {
 			*ret_w = (guint) gst_util_uint64_scale (video_h, dar_n, dar_d);
-			*ret_h = video_w;
+			*ret_h = video_h;
 		    }
 		    TRACE ("Got best video size %dx%d fraction, %d/%d\n", *ret_w, *ret_h, disp_par_n, disp_par_d);
 		}
@@ -497,7 +505,7 @@ parole_gst_set_video_color_balance (ParoleGst *gst)
 }
 
 static void
-parole_gst_set_x_overlay (ParoleGst *gst)
+parole_gst_set_video_overlay (ParoleGst *gst)
 {
     GstElement *video_sink;
     
@@ -508,11 +516,15 @@ parole_gst_set_x_overlay (ParoleGst *gst)
     g_assert (video_sink != NULL);
     
     if ( GDK_IS_WINDOW (GTK_WIDGET (gst)->window) )
-	gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (video_sink),
+#if GST_CHECK_VERSION(1, 0, 0)
+	gst_video_overlay_set_window_handle (GST_VIDEO_OVERLAY (video_sink),
 				      GDK_WINDOW_XWINDOW (GTK_WIDGET (gst)->window));
+#else
+    gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (video_sink),
+                      GDK_WINDOW_XWINDOW (GTK_WIDGET (gst)->window));
+#endif
     
     gst_object_unref (video_sink);
-    
 }
 
 static gboolean
@@ -531,7 +543,7 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 		  "has-video", &playing_video,
 		  NULL);
 
-    parole_gst_set_x_overlay (gst);
+    parole_gst_set_video_overlay (gst);
 
     TRACE ("EXPOSE event state=%d  target=%d", gst->priv->state, gst->priv->target);
     
@@ -540,14 +552,22 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 	case GST_STATE_PLAYING:
 	    if ( playing_video || gst->priv->vis_loaded)
 	    {
-		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#if GST_CHECK_VERSION(1, 0, 0)
+		gst_video_overlay_expose (GST_VIDEO_OVERLAY (gst->priv->video_sink));
+#else
+        gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#endif
 	    }
 	    else
 		parole_gst_draw_logo (gst);
 	    break;
 	case GST_STATE_PAUSED:
 	    if ( playing_video || gst->priv->vis_loaded || gst->priv->target == GST_STATE_PLAYING )
-		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#if GST_CHECK_VERSION(1, 0, 0)
+		gst_video_overlay_expose (GST_VIDEO_OVERLAY (gst->priv->video_sink));
+#else
+        gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#endif
 	    else
 		parole_gst_draw_logo (gst);
 	    break;
@@ -555,7 +575,11 @@ parole_gst_expose_event (GtkWidget *widget, GdkEventExpose *ev)
 	    if (gst->priv->target != GST_STATE_PLAYING)
 		parole_gst_draw_logo (gst);
 	    else
-		gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#if GST_CHECK_VERSION(1, 0, 0)
+		gst_video_overlay_expose (GST_VIDEO_OVERLAY (gst->priv->video_sink));
+#else
+        gst_x_overlay_expose (GST_X_OVERLAY (gst->priv->video_sink));
+#endif
 	    break;
 	case GST_STATE_NULL:
 	case GST_STATE_VOID_PENDING:
@@ -605,15 +629,14 @@ static gboolean
 parole_gst_tick_timeout (gpointer data)
 {
     ParoleGst *gst;
+    GstFormat format = GST_FORMAT_TIME;
     
     gint64 pos;
-    GstFormat format = GST_FORMAT_TIME;
     gint64 value;
     gboolean video;
     gboolean seekable;
     gint64 duration;
     
-    
     gst = PAROLE_GST (data);
     
     g_object_get (G_OBJECT (gst->priv->stream),
@@ -622,11 +645,15 @@ parole_gst_tick_timeout (gpointer data)
 		  "duration", &duration,
 		  NULL);
     
+#if GST_CHECK_VERSION(1, 0, 0)
+    gst_element_query_position (gst->priv->playbin, format, &pos);
+#else
     gst_element_query_position (gst->priv->playbin, &format, &pos);
     
     if ( G_UNLIKELY (format != GST_FORMAT_TIME ) )
-	goto out;
-
+        goto out;
+#endif
+    
     if ( gst->priv->state == GST_STATE_PLAYING )
     {
 	if (duration != 0 && seekable == FALSE)
@@ -640,9 +667,12 @@ parole_gst_tick_timeout (gpointer data)
 	    g_signal_emit (G_OBJECT (gst), signals [MEDIA_PROGRESSED], 0, gst->priv->stream, value);
     }
 
+#if GST_CHECK_VERSION(1, 0, 0)
+#else
 out:
     if ( g_timer_elapsed (gst->priv->hidecursor_timer, NULL ) > HIDE_WINDOW_CURSOR_TIMEOUT && video)
 	parole_gst_set_cursor_visible (gst, FALSE);
+#endif
 	
     return TRUE;
 }
@@ -677,26 +707,28 @@ parole_gst_query_duration (ParoleGst *gst)
     gint64 absolute_duration = 0;
     gint64 duration = 0;
     gboolean live;
-    GstFormat gst_time;
+    GstFormat gst_time = GST_FORMAT_TIME;
     
-    gst_time = GST_FORMAT_TIME;
-    
-    gst_element_query_duration (gst->priv->playbin, 
-				&gst_time,
-				&absolute_duration);
+    gst_element_query_duration (gst->priv->playbin,
+#if GST_CHECK_VERSION(1, 0, 0)
+                                gst_time,
+#else
+                                &gst_time,
+#endif
+                                &absolute_duration);
     
     if (gst_time == GST_FORMAT_TIME)
     {
-	duration =  absolute_duration / GST_SECOND;
-	live = ( absolute_duration == 0 );
-	
-	TRACE ("Duration %" G_GINT64_FORMAT "is_live=%d", duration, live);
-	
-	g_object_set (G_OBJECT (gst->priv->stream),
-		      "absolute-duration", absolute_duration,
-		      "duration", duration,
-		      "live", live,
-		      NULL);
+        duration =  absolute_duration / GST_SECOND;
+        live = ( absolute_duration == 0 );
+
+        TRACE ("Duration %" G_GINT64_FORMAT "is_live=%d", duration, live);
+
+        g_object_set (G_OBJECT (gst->priv->stream),
+              "absolute-duration", absolute_duration,
+              "duration", duration,
+              "live", live,
+              NULL);
     }
 }
 
@@ -784,14 +816,27 @@ parole_gst_get_pad_capabilities (GObject *object, GParamSpec *pspec, ParoleGst *
     guint num;
     guint den;
     const GValue *value;
+#if GST_CHECK_VERSION(1, 0, 0)
+    GstCaps *caps;
+#endif
     
     pad = GST_PAD (object);
+    if ( !GST_IS_PAD (pad) )
+        return;
+        
+#if GST_CHECK_VERSION(1, 0, 0)
+    caps = gst_pad_get_current_caps (pad);
+    if ( !caps )
+        return;
     
+    st = gst_caps_get_structure (caps, 0);
+#else
     if ( !GST_IS_PAD (pad) || !GST_PAD_CAPS (pad) )
-	return;
+    return;
     
     st = gst_caps_get_structure (GST_PAD_CAPS (pad), 0);
-    
+#endif
+	
     if ( st )
     {
 	gst_structure_get_int (st, "width", &width);
@@ -815,6 +860,9 @@ parole_gst_get_pad_capabilities (GObject *object, GParamSpec *pspec, ParoleGst *
 
 	parole_gst_size_allocate (GTK_WIDGET (gst), &GTK_WIDGET (gst)->allocation);
     }
+#if GST_CHECK_VERSION(1, 0, 0)
+    gst_caps_unref (caps);
+#endif
 }
 
 static void
@@ -843,7 +891,11 @@ parole_gst_query_info (ParoleGst *gst)
 	{
 	    GstCaps *caps;
 	    
-	    if ((caps = gst_pad_get_negotiated_caps (videopad)))
+#if GST_CHECK_VERSION(1, 0, 0)
+	    if ((caps = gst_pad_get_current_caps (videopad)))
+#else
+        if ((caps = gst_pad_get_negotiated_caps (videopad)))
+#endif
 	    {
 		parole_gst_get_pad_capabilities (G_OBJECT (videopad), NULL, gst);
 		gst_caps_unref (caps);
@@ -1003,13 +1055,21 @@ parole_gst_evaluate_state (ParoleGst *gst, GstState old, GstState new, GstState
 static void
 parole_gst_element_message_sync (GstBus *bus, GstMessage *message, ParoleGst *gst)
 {
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_message_has_name (message, "prepare-xwindow-id") )
+#else
     if ( !message->structure )
-	goto out;
-	
+        goto out;
+        
     if ( gst_structure_has_name (message->structure, "prepare-xwindow-id") )
-	parole_gst_set_x_overlay (gst);
+#endif
+	parole_gst_set_video_overlay (gst);
+	
+#if GST_CHECK_VERSION (1, 0, 0)
+#else
 out:
     ;
+#endif
 }
 
 static GdkPixbuf *
@@ -1018,10 +1078,20 @@ parole_gst_buffer_to_pixbuf (GstBuffer *buffer)
   GdkPixbufLoader *loader;
   GdkPixbuf *pixbuf = NULL;
   GError *err = NULL;
+#if GST_CHECK_VERSION (1, 0, 0)
+  GstMapInfo map;
+
+  if (!gst_buffer_map (buffer, &map, GST_MAP_READ))
+    return NULL;
+#endif
 
   loader = gdk_pixbuf_loader_new ();
-
+  
+#if GST_CHECK_VERSION (1, 0, 0)
+  if (gdk_pixbuf_loader_write (loader, map.data, map.size, &err) &&
+#else
   if (gdk_pixbuf_loader_write (loader, buffer->data, buffer->size, &err) &&
+#endif
       gdk_pixbuf_loader_close (loader, &err)) {
     pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
     if (pixbuf)
@@ -1031,13 +1101,18 @@ parole_gst_buffer_to_pixbuf (GstBuffer *buffer)
     g_error_free (err);
   }
 
+#if GST_CHECK_VERSION (1, 0, 0)
+  gst_buffer_unmap (buffer, &map);
+#endif
   g_object_unref (loader);
   return pixbuf;
 }
 
-gchar *
+GdkPixbuf *
 parole_gst_tag_list_get_cover_external (ParoleGst *gst)
 {
+    GdkPixbuf *pixbuf;
+    GError *err = NULL;
     gchar *uri;
     gchar *filename;
     gchar *directory;
@@ -1088,82 +1163,129 @@ parole_gst_tag_list_get_cover_external (ParoleGst *gst)
     g_free(directory);
     g_free(file_dir);
     g_free(lower);
-    return cover_filename;
+    
+    if (!cover_filename)
+        return NULL;
+
+    pixbuf = gdk_pixbuf_new_from_file(cover_filename, &err);
+    g_free(cover_filename);
+    if (err)
+    {
+        g_object_unref(pixbuf);
+        g_error_free(err);
+        return NULL;
+    }
+    return pixbuf;
 }
 
-static const GValue *
-parole_gst_tag_list_get_cover_real (GstTagList *tag_list)
+GdkPixbuf *
+parole_gst_tag_list_get_cover_embedded (ParoleGst *gst, GstTagList *tag_list)
 {
-  const GValue *cover_value = NULL;
-  guint i;
+    GdkPixbuf *pixbuf;
+    const GValue *cover_value = NULL;
+    guint i;
 
-  for (i = 0; ; i++) {
-    const GValue *value;
-    GstBuffer *buffer;
-    GstStructure *caps_struct;
-    int type;
+    for (i = 0; ; i++) {
+        const GValue *value;
+#if GST_CHECK_VERSION(1, 0, 0)
+        GstSample *sample;
+#else
+        GstBuffer *buffer;
+#endif
+        GstStructure *caps_struct;
+        int type;
 
-    value = gst_tag_list_get_value_index (tag_list,
-					  GST_TAG_IMAGE,
-					  i);
-    if (value == NULL)
-      break;
+        value = gst_tag_list_get_value_index (tag_list,
+                                              GST_TAG_IMAGE,
+                                              i);
+        if (value == NULL)
+            break;
 
-    buffer = gst_value_get_buffer (value);
+#if GST_CHECK_VERSION(1, 0, 0)
+        sample = gst_value_get_sample (value);
+        caps_struct = gst_caps_get_structure (gst_sample_get_caps(sample), 0);
+#else
+        buffer = gst_value_get_buffer (value);
+        caps_struct = gst_caps_get_structure (buffer->caps, 0);
+#endif
 
-    caps_struct = gst_caps_get_structure (buffer->caps, 0);
-    
-    gst_structure_get_enum (caps_struct,
-			    "image-type",
-			    GST_TYPE_TAG_IMAGE_TYPE,
-			    &type);
-    if (type == GST_TAG_IMAGE_TYPE_UNDEFINED) {
-      if (cover_value == NULL)
-        cover_value = value;
-    } else if (type == GST_TAG_IMAGE_TYPE_FRONT_COVER) {
-      cover_value = value;
-      break;
+        gst_structure_get_enum (caps_struct,
+                                "image-type",
+                                GST_TYPE_TAG_IMAGE_TYPE,
+                                &type);
+        if (type == GST_TAG_IMAGE_TYPE_UNDEFINED) {
+            if (cover_value == NULL)
+                cover_value = value;
+        } else if (type == GST_TAG_IMAGE_TYPE_FRONT_COVER) {
+            cover_value = value;
+            break;
+        }
     }
-  }
 
-  return cover_value;
+    if (!cover_value) {
+        cover_value = gst_tag_list_get_value_index (tag_list,
+        GST_TAG_PREVIEW_IMAGE,
+        0);
+    }
+
+    if (cover_value) {
+#if GST_CHECK_VERSION(1, 0, 0)
+        GstSample *sample;
+        sample = gst_value_get_sample (cover_value);
+        pixbuf = parole_gst_buffer_to_pixbuf (gst_sample_get_buffer (sample));
+#else
+        GstBuffer *buffer;
+        buffer = gst_value_get_buffer (cover_value);
+        pixbuf = parole_gst_buffer_to_pixbuf (buffer);
+#endif
+        return pixbuf;
+    }
+    return NULL;
 }
 
 GdkPixbuf *
 parole_gst_tag_list_get_cover (ParoleGst *gst, GstTagList *tag_list)
 {
-  gchar *cover_filename;
-  const GValue *cover_value;
-  
-
-  g_return_val_if_fail (tag_list != NULL, FALSE);
-  
-  cover_filename = parole_gst_tag_list_get_cover_external(gst);
-  if (cover_filename)
-  {
-    GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size(cover_filename, 256, 256, NULL);
-    if (pixbuf)
-        return pixbuf;
-  }
-
-  cover_value = parole_gst_tag_list_get_cover_real (tag_list);
-  /* Fallback to preview */
-  if (!cover_value) {
-    cover_value = gst_tag_list_get_value_index (tag_list,
-						GST_TAG_PREVIEW_IMAGE,
-						0);
-  }
-
-  if (cover_value) {
-    GstBuffer *buffer;
     GdkPixbuf *pixbuf;
+    GdkPixbuf *scaled;
+    gint height, width;
+    gfloat multiplier;
+  
+    g_return_val_if_fail (tag_list != NULL, FALSE);
+    
+    pixbuf = parole_gst_tag_list_get_cover_external(gst);
+    if (!pixbuf)
+    {
+        pixbuf = parole_gst_tag_list_get_cover_embedded(gst, tag_list);
+        if (!pixbuf)
+            return NULL;
+    }
 
-    buffer = gst_value_get_buffer (cover_value);
-    pixbuf = parole_gst_buffer_to_pixbuf (buffer);
-    return pixbuf;
-  }
+    if (gdk_pixbuf_get_width(pixbuf) == gdk_pixbuf_get_height(pixbuf))
+    {
+        height = 256;
+        width = 256;
+    }
+    else if (gdk_pixbuf_get_width(pixbuf) < gdk_pixbuf_get_height(pixbuf))
+    {
+        multiplier = gdk_pixbuf_get_height(pixbuf)/256.0;
+        height = 256;
+        width = gdk_pixbuf_get_width(pixbuf) / multiplier;
+    }
+    else
+    {
+        multiplier = gdk_pixbuf_get_width(pixbuf)/256.0;
+        height = gdk_pixbuf_get_height(pixbuf)/multiplier;
+        width = 256;
+    }
+    
+    scaled = gdk_pixbuf_scale_simple (pixbuf,
+                                      width,
+                                      height,
+                                      GDK_INTERP_HYPER);
 
-  return NULL;
+    g_object_unref(pixbuf);
+    return scaled;
 }
 
 static void
@@ -1176,20 +1298,25 @@ parole_gst_get_meta_data_dvd (ParoleGst *gst)
     guint current_chapter;
     gint64 val = -1;
     
-    GstFormat format;
+    GstFormat format = gst_format_get_by_nick ("chapter");
+    
+    TRACE("START");
     
     g_object_get (  G_OBJECT (gst->priv->stream),
                     "num-tracks", &current_num_chapters,
 		            "track", &current_chapter,
 		            NULL);
 
-    format = gst_format_get_by_nick ("chapter");
-
     /* Get the number of chapters for the current title. */
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_element_query_duration (gst->priv->playbin, format, &val) )
+#else
     if ( gst_element_query_duration (gst->priv->playbin, &format, &val) )
+#endif
     {
         n_chapters = (gint) val;
         num_chapters = (guint) n_chapters;
+        TRACE("Number of chapters: %i", n_chapters);
         if (num_chapters != current_num_chapters)
         {
             g_object_set (G_OBJECT (gst->priv->stream),
@@ -1204,9 +1331,14 @@ parole_gst_get_meta_data_dvd (ParoleGst *gst)
     
     /* Get the current chapter. */
     val = -1;
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_element_query_position (gst->priv->playbin, format, &val) )
+#else
     if ( gst_element_query_position (gst->priv->playbin, &format, &val) )
+#endif
     {
         chapter = (guint)(gint) val;
+        TRACE("Current chapter: %i", chapter);
         if ( chapter != current_chapter || num_chapters != 1 )
         {
             g_object_set (G_OBJECT (gst->priv->stream),
@@ -1375,20 +1507,26 @@ parole_gst_get_meta_data (ParoleGst *gst, GstTagList *tag)
 static void
 parole_gst_application_message (ParoleGst *gst, GstMessage *msg)
 {
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_message_has_name (msg, "notify-streaminfo") )
+#else
     const gchar *name;
-
     name = gst_structure_get_name (msg->structure);
     
     if ( !name )
-	return;
-	
-    TRACE ("Application message : %s", name);
+        return;
     
     if ( !g_strcmp0 (name, "notify-streaminfo") )
+#endif
     {
 	parole_gst_update_stream_info (gst);
     }
+    
+#if GST_CHECK_VERSION(1, 0, 0)
+    else if ( gst_message_has_name (msg, "video-size") )
+#else
     else if ( !g_strcmp0 (name, "video-size") )
+#endif
     {
 	parole_gst_size_allocate (GTK_WIDGET (gst), &GTK_WIDGET (gst)->allocation);
     }
@@ -1557,8 +1695,21 @@ parole_gst_bus_event (GstBus *bus, GstMessage *msg, gpointer data)
 	             details[0] = gst_missing_plugin_message_get_installer_detail(msg);
 	             details[1] = NULL;
 	             ctx = gst_install_plugins_context_new();
-	             gst_install_plugins_async(details, ctx, parole_gst_install_plugins_result_func, gst);
 	             
+#ifdef GDK_WINDOWING_X11
+            if (gtk_widget_get_window (GTK_WIDGET (gst)) != NULL &&
+                gtk_widget_get_realized (GTK_WIDGET (gst)))
+            {
+                gst_install_plugins_context_set_xid (ctx,
+                    GDK_WINDOW_XID (GTK_WIDGET (gst)->window));
+            }
+#endif /* GDK_WINDOWING_X11 */
+
+#if GST_CHECK_VERSION(1, 0, 0)
+	             gst_install_plugins_async((const gchar * const *) details, ctx, parole_gst_install_plugins_result_func, gst);
+#else
+                 gst_install_plugins_async(details, ctx, parole_gst_install_plugins_result_func, gst);
+#endif
 	             gst_install_plugins_context_free(ctx);
 	        }
 	        else if ( response == GTK_RESPONSE_REJECT )
@@ -1794,7 +1945,11 @@ parole_gst_seek_by_format (ParoleGst *gst, GstFormat format, gint step)
 {
     gint64 val = 1;
     
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_element_query_position (gst->priv->playbin, format, &val) )
+#else
     if ( gst_element_query_position (gst->priv->playbin, &format, &val) )
+#endif
     {
 	val += step;
 	if ( !gst_element_seek (gst->priv->playbin, 1.0, format, 
@@ -1815,9 +1970,7 @@ parole_gst_seek_by_format (ParoleGst *gst, GstFormat format, gint step)
 static void
 parole_gst_change_dvd_chapter (ParoleGst *gst, gint level)
 {
-    GstFormat format;
-
-    format = gst_format_get_by_nick ("chapter");
+    GstFormat format = gst_format_get_by_nick ("chapter");
     
     parole_gst_seek_by_format (gst, format, level);
 }
@@ -1825,9 +1978,7 @@ parole_gst_change_dvd_chapter (ParoleGst *gst, gint level)
 static void
 parole_gst_change_cdda_track (ParoleGst *gst, gint level)
 {
-    GstFormat format;
-    
-    format = gst_format_get_by_nick ("track");
+    GstFormat format = gst_format_get_by_nick ("track");
     
     parole_gst_seek_by_format (gst, format, level);
 }
@@ -2021,7 +2172,11 @@ parole_gst_constructed (GObject *object)
 		  "enable-xv", &enable_xv,
 		  NULL);
     
+#if GST_CHECK_VERSION(1, 0, 0)
+    gst->priv->playbin = gst_element_factory_make ("playbin", "player");
+#else
     gst->priv->playbin = gst_element_factory_make ("playbin2", "player");
+#endif
  
     if ( G_UNLIKELY (gst->priv->playbin == NULL) )
     {
@@ -2077,7 +2232,11 @@ parole_gst_constructed (GObject *object)
      * Handling 'prepare-xwindow-id' message async causes XSync 
      * error in some occasions So we handle this message synchronously
      */
+#if GST_CHECK_VERSION(1, 0, 0)
+    gst_bus_set_sync_handler (gst->priv->bus, gst_bus_sync_signal_handler, gst, NULL);
+#else
     gst_bus_set_sync_handler (gst->priv->bus, gst_bus_sync_signal_handler, gst);
+#endif
     gst->priv->sig2 =
 	g_signal_connect (gst->priv->bus, "sync-message::element",
 			  G_CALLBACK (parole_gst_element_message_sync), gst);
@@ -2452,34 +2611,14 @@ void parole_gst_shutdown (ParoleGst *gst)
     g_object_unref (gst->priv->playbin);
 }
 
-void parole_gst_seek (ParoleGst *gst, gdouble pos)
+void parole_gst_seek (ParoleGst *gst, gdouble seek)
 {
-    gint64 seek;
-    gint64 absolute_duration;
-    gint64 duration;
-    gboolean seekable;
-
     TRACE ("Seeking");
-
-    g_object_get (G_OBJECT (gst->priv->stream),
-		  "absolute-duration", &absolute_duration,
-		  "duration", &duration,
-		  "seekable", &seekable,
-		  NULL);
-		  
-#ifdef DEBUG
-    g_return_if_fail (duration != 0);
-    g_return_if_fail (absolute_duration != 0);
-    g_return_if_fail (seekable == TRUE);
-#endif
-	
-    seek = (pos * absolute_duration) / duration;
-    
     g_warn_if_fail ( gst_element_seek (gst->priv->playbin,
 				       1.0,
 				       GST_FORMAT_TIME,
 				       GST_SEEK_FLAG_KEY_UNIT | GST_SEEK_FLAG_FLUSH,
-				       GST_SEEK_TYPE_SET, seek,
+				       GST_SEEK_TYPE_SET, (int) seek * GST_SECOND,
 				       GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE));
 }
 
@@ -2559,13 +2698,15 @@ void parole_gst_seek_cdda	(ParoleGst *gst, guint track_num)
 
 gint parole_gst_get_current_cdda_track (ParoleGst *gst)
 {
-    GstFormat format;
+    GstFormat format = gst_format_get_by_nick ("track");
     gint64 pos;
     gint ret_val = 1;
     
-    format = gst_format_get_by_nick ("track");
-    
+#if GST_CHECK_VERSION(1, 0, 0)
+    if ( gst_element_query_position (gst->priv->playbin, format, &pos) )
+#else
     if ( gst_element_query_position (gst->priv->playbin, &format, &pos) )
+#endif
     {
 	TRACE ("Pos %" G_GINT64_FORMAT, pos);
 	ret_val = (gint) pos;
@@ -2589,7 +2730,11 @@ gint64 parole_gst_get_stream_position (ParoleGst *gst)
     GstFormat format = GST_FORMAT_TIME;
     gint64 pos;
     
+#if GST_CHECK_VERSION(1, 0, 0)
+    gst_element_query_position (gst->priv->playbin, format, &pos);
+#else
     gst_element_query_position (gst->priv->playbin, &format, &pos);
+#endif
     
     return  pos / GST_SECOND;
 }
@@ -2614,93 +2759,105 @@ parole_gst_set_cursor_visible (ParoleGst *gst, gboolean visible)
 GList *
 gst_get_lang_list_for_type (ParoleGst * gst, const gchar * type_name)
 {
-  GList *ret = NULL;
-  gint num = 1;
+    GList *ret = NULL;
+    gint num = 1;
 
-  if (g_str_equal (type_name, "AUDIO")) {
-    gint i, n;
+    if (g_str_equal (type_name, "AUDIO")) {
+        gint i, n;
 
-    g_object_get (G_OBJECT (gst->priv->playbin), "n-audio", &n, NULL);
-    if (n == 0)
-      return NULL;
+        g_object_get (G_OBJECT (gst->priv->playbin), "n-audio", &n, NULL);
+        if (n == 0)
+            return NULL;
 
-    for (i = 0; i < n; i++) {
-      GstTagList *tags = NULL;
-
-      g_signal_emit_by_name (G_OBJECT (gst->priv->playbin), "get-audio-tags",
-          i, &tags);
-
-      if (tags) {
-        gchar *lc = NULL, *cd = NULL;
-
-	gst_tag_list_get_string (tags, GST_TAG_LANGUAGE_CODE, &lc);
-	gst_tag_list_get_string (tags, GST_TAG_CODEC, &lc);
-
-        if (lc) {
-	  ret = g_list_prepend (ret, lc);
-	  g_free (cd);
-	} else if (cd) {
-	  ret = g_list_prepend (ret, cd);
-	} else {
-	  ret = g_list_prepend (ret, g_strdup_printf (_("Audio Track #%d"), num++));
-	}
-	gst_tag_list_free (tags);
-      } else {
-	ret = g_list_prepend (ret, g_strdup_printf (_("Audio Track #%d"), num++));
-      }
-    }
-  } else if (g_str_equal (type_name, "TEXT")) {
-    gint i, n = 0;
-
-    g_object_get (G_OBJECT (gst->priv->playbin), "n-text", &n, NULL);
-    
-    if (n == 0 && gst->priv->use_custom_subtitles == FALSE)
-      return NULL;
-      
-    if ( gst->priv->use_custom_subtitles == TRUE )
-        n--;
-
-    if (n != 0)
-    {
         for (i = 0; i < n; i++) {
-          GstTagList *tags = NULL;
+            GstTagList *tags = NULL;
 
-          g_signal_emit_by_name (G_OBJECT (gst->priv->playbin), "get-text-tags",
-              i, &tags);
+            g_signal_emit_by_name (G_OBJECT (gst->priv->playbin), "get-audio-tags",
+                i, &tags);
 
-          if (tags) {
-            gchar *lc = NULL, *cd = NULL;
+            if (tags) {
+                gchar *lc = NULL, *cd = NULL, *language_name = NULL;
+                
+                gst_tag_list_get_string (tags, GST_TAG_LANGUAGE_CODE, &lc);
+                gst_tag_list_get_string (tags, GST_TAG_CODEC, &cd);
 
-	    gst_tag_list_get_string (tags, GST_TAG_LANGUAGE_CODE, &lc);
-	    gst_tag_list_get_string (tags, GST_TAG_CODEC, &lc);
-	
-            if (lc) {
-	      ret = g_list_prepend (ret, lc);
-	      g_free (cd);
-	    } else if (cd) {
-	      ret = g_list_prepend (ret, cd);
-	    } else {
-	      ret = g_list_prepend (ret, g_strdup_printf (_("Subtitle #%d"), num++));
-	    }
-	    gst_tag_list_free (tags);
-          } else {
-	    ret = g_list_prepend (ret, g_strdup_printf (_("Subtitle #%d"), num++));
-          }
+                if (lc) {
+                    language_name = g_strdup(gst_tag_get_language_name(lc));
+                    if (language_name)
+                    {
+                        ret = g_list_prepend (ret, language_name);
+                    }
+                    else
+                        ret = g_list_prepend (ret, lc);
+                    g_free (cd);
+                } else if (cd) {
+                    ret = g_list_prepend (ret, cd);
+                } else {
+                    ret = g_list_prepend (ret, g_strdup_printf (_("Audio Track #%d"), num++));
+                }
+                gst_tag_list_free (tags);
+            } else {
+                ret = g_list_prepend (ret, g_strdup_printf (_("Audio Track #%d"), num++));
+            }
         }
-    }
-    
-    ret = g_list_reverse (ret);
-    
-    if ( gst->priv->use_custom_subtitles == TRUE )
-    {
-        ret = g_list_prepend (ret, g_strdup_printf("%s",gst->priv->custom_subtitles));
-    }
-  } else {
-    g_critical ("Invalid stream type '%s'", type_name);
-    return NULL;
-  }
+    } else if (g_str_equal (type_name, "TEXT")) {
+        gint i, n = 0;
 
-  return ret;
+        g_object_get (G_OBJECT (gst->priv->playbin), "n-text", &n, NULL);
+        
+        if (n == 0 && gst->priv->use_custom_subtitles == FALSE)
+            return NULL;
+          
+        if ( gst->priv->use_custom_subtitles == TRUE )
+            n--;
+
+        if (n != 0)
+        {
+            for (i = 0; i < n; i++) {
+                GstTagList *tags = NULL;
+
+                g_signal_emit_by_name (G_OBJECT (gst->priv->playbin), "get-text-tags",
+                    i, &tags);
+
+                if (tags) {
+                    gchar *lc = NULL, *cd = NULL, *language_name = NULL;
+
+                gst_tag_list_get_string (tags, GST_TAG_LANGUAGE_CODE, &lc);
+                gst_tag_list_get_string (tags, GST_TAG_CODEC, &lc);
+
+                if (lc) {
+                    language_name = g_strdup(gst_tag_get_language_name(lc));
+                    if (language_name)
+                    {
+                        ret = g_list_prepend (ret, language_name);
+                    }
+                    else
+                        ret = g_list_prepend (ret, lc);
+                    g_free (cd);
+                } else if (cd) {
+                    ret = g_list_prepend (ret, cd);
+                } else {
+                    ret = g_list_prepend (ret, g_strdup_printf (_("Subtitle #%d"), num++));
+                }
+                gst_tag_list_free (tags);
+                } else {
+                    ret = g_list_prepend (ret, g_strdup_printf (_("Subtitle #%d"), num++));
+                }
+            }
+        }
+        
+        ret = g_list_reverse (ret);
+        
+        if ( gst->priv->use_custom_subtitles == TRUE )
+        {
+            ret = g_list_prepend (ret, g_strdup_printf("%s",gst->priv->custom_subtitles));
+        }
+    } else {
+        g_critical ("Invalid stream type '%s'", type_name);
+        return NULL;
+    }
+
+    return ret;
 }
 
 gboolean
