@@ -55,7 +55,7 @@
 
 #include "common/parole-common.h"
 
-#define PAROLE_AUTO_SAVED_PLAYLIST 	"xfce4/src/misc/auto-saved-playlist.m3u"
+#define PAROLE_AUTO_SAVED_PLAYLIST 	"xfce4/parole/auto-saved-playlist.m3u"
 
 typedef struct
 {
@@ -155,7 +155,7 @@ gboolean	parole_media_list_query_tooltip		(GtkWidget *widget,
 							 ParoleMediaList *list);
 							 
 void		parole_media_list_menu_pos (GtkMenu *menu, 
-							gint *px, gint *py, gpointer data);
+							gint *px, gint *py, gboolean *push_in, gpointer data);
 
 void parole_media_list_send_dvd_menu_navigation (ParoleMediaList *list, gint msg_id);
 
@@ -200,6 +200,7 @@ struct ParoleMediaListPrivate
     GtkWidget *repeat_button;
     GtkWidget *shuffle_button;
 	GtkWidget *settings_button;
+	GtkWidget *n_items;
 };
 
 enum
@@ -297,10 +298,30 @@ parole_media_list_add (ParoleMediaList *list, ParoleFile *file, gboolean disc, g
     {
 	gtk_widget_set_sensitive (list->priv->remove_button, TRUE);
 	gtk_widget_set_sensitive (list->priv->clear_button, TRUE);
+	if (gtk_notebook_get_current_page(GTK_NOTEBOOK(list->priv->playlist_notebook)) == 0)
+	{
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i item"),nch));
+	}
+	else
+	{
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i chapter"),nch));
+	}
     }
     else
+    {
 	parole_media_list_set_widget_sensitive (list, TRUE);
-	
+	if (gtk_notebook_get_current_page(GTK_NOTEBOOK(list->priv->playlist_notebook)) == 0)
+	{
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i items"),nch));
+	}
+	else
+	{
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i chapters"),nch));
+	}
+    }
+    gtk_widget_show (list->priv->n_items);
+    if ( nch == 0 )
+	    gtk_widget_hide (list->priv->n_items);
 }
 
 /**
@@ -969,12 +990,18 @@ parole_media_list_remove_clicked_cb (GtkButton *button, ParoleMediaList *list)
     if ( nch == 0)
     {
 	parole_media_list_set_widget_sensitive (list, FALSE);
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),_("Playlist empty"));
+	gtk_widget_hide (list->priv->n_items);
 	/*
 	 * Will emit the signal media_cursor_changed with FALSE because there is no any 
 	 * row remaining, so the player can disable click on the play button.
 	 */
 	g_signal_emit (G_OBJECT (list), signals [MEDIA_CURSOR_CHANGED], 0, FALSE);
     }
+    else if ( nch == 1 )
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i item"),nch));
+    else
+	gtk_label_set_text (GTK_LABEL(list->priv->n_items),g_strdup_printf (_("%i items"),nch));
 }
 
 /**
@@ -1107,6 +1134,8 @@ parole_media_list_clear_list (ParoleMediaList *list)
     TRACE("CLEAR START");
     gtk_list_store_clear (GTK_LIST_STORE (list->priv->store));
     parole_media_list_set_widget_sensitive (list, FALSE);
+    gtk_label_set_text (GTK_LABEL(list->priv->n_items),_("Playlist empty"));
+    gtk_widget_hide (list->priv->n_items);
     TRACE("CLEAR END");
 }
 
@@ -1150,12 +1179,14 @@ shuffle_activated_cb (GtkWidget *mi, ParoleMediaList *list)
 }
 
 void
-parole_media_list_menu_pos (GtkMenu *menu, gint *px, gint *py, gpointer data)
+parole_media_list_menu_pos (GtkMenu *menu, gint *px, gint *py, gboolean *push_in, gpointer data)
 {
 	gint x, y;
 	GtkAllocation widget_allocation, menu_allocation;
 	GtkWidget *widget = gtk_menu_get_attach_widget( menu );
 	GdkWindow *window;
+
+    *push_in = TRUE;
 	
 	gtk_widget_get_allocation( widget, &widget_allocation );
 	gtk_widget_get_allocation( GTK_WIDGET(menu), &menu_allocation );
@@ -1166,8 +1197,8 @@ parole_media_list_menu_pos (GtkMenu *menu, gint *px, gint *py, gpointer data)
 	if (widget_allocation.width > 100)
 	gtk_widget_set_size_request(GTK_WIDGET(menu), widget_allocation.width, -1);
 	
-	*px = x + widget_allocation.x;
-	*py = y + widget_allocation.y + widget_allocation.height;
+    *px = x + widget_allocation.x;
+    *py = y + widget_allocation.y + widget_allocation.height;
 }
 
 static void
@@ -1691,6 +1722,7 @@ parole_media_list_init (ParoleMediaList *list)
     list->priv->repeat_button = GTK_WIDGET (gtk_builder_get_object (builder, "repeat-media"));
     list->priv->shuffle_button = GTK_WIDGET (gtk_builder_get_object (builder, "shuffle-media"));
     list->priv->settings_button = GTK_WIDGET (gtk_builder_get_object (builder, "settings"));
+    list->priv->n_items = GTK_WIDGET (gtk_builder_get_object (builder, "n_items"));
     
     g_signal_connect (GTK_TOGGLE_BUTTON(list->priv->settings_button), "toggled",
 		      G_CALLBACK (parole_media_list_show_button_menu), list);
@@ -2009,6 +2041,34 @@ void parole_media_list_set_row_pixbuf  (ParoleMediaList *list, GtkTreeRowReferen
     }
 }
 
+gchar* parole_media_list_get_row_name (ParoleMediaList *list,
+GtkTreeRowReference *row)
+{
+    GtkTreeIter iter;
+    GtkTreePath *path;
+    gchar *name = NULL;
+    
+    if ( gtk_tree_row_reference_valid (row) )
+    {
+	path = gtk_tree_row_reference_get_path (row);
+	
+	if (gtk_notebook_get_current_page(GTK_NOTEBOOK(list->priv->playlist_notebook)) == 0)
+	{
+    	if ( gtk_tree_model_get_iter (GTK_TREE_MODEL (list->priv->store), &iter, path) )
+    	    gtk_tree_model_get (GTK_TREE_MODEL(list->priv->store), &iter, NAME_COL, &name, -1);
+	}
+	else
+	{
+    	if ( gtk_tree_model_get_iter (GTK_TREE_MODEL (list->priv->disc_store), &iter, path) )
+    	    gtk_tree_model_get (GTK_TREE_MODEL(list->priv->store), &iter, NAME_COL, &name, -1);
+	}
+	
+	gtk_tree_path_free (path);
+    }
+    
+    return name;
+}
+
 void parole_media_list_set_row_name (ParoleMediaList *list, GtkTreeRowReference *row, const gchar *name)
 {
     GtkTreeIter iter;
